@@ -372,7 +372,7 @@ def info():
 @Dispatcher.attach("fastdeploy")
 @jail
 def fastdeploy():
-    check_some_options(("appname", "url", "profilename"))
+    check_some_options(("appname", "url", "profile"))
     task = {"appname": options.appname,
             "version": options.version,
             "environment": options.environment,
